Coverage for vcr.persist: 80%

# Coverage for vcr.persist : 80%

## 10 statements 8 run 2 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 | from .persisters.filesystem import FilesystemPersister from .serialize import serialize, deserialize def load_cassette(cassette_path, serializer): with open(cassette_path) as f: cassette_content = f.read() cassette = deserialize(cassette_content, serializer) return cassette def save_cassette(cassette_path, cassette_dict, serializer): data = serialize(cassette_dict, serializer) FilesystemPersister.write(cassette_path, data)